from .seeker import CodeSeeker

__all__ = 'ISO3166_SEEKER',

ISO3166_SEEKER = CodeSeeker(name='ISO3166')
